#	ZXMedia: ZX Spectrum file format manipulation library
#	Copyright (C) 2004 Matthew Westcott
#	
#	This file is part of ZXMedia.
#	
#	ZXMedia is free software; you can redistribute it and/or modify
#	it under the terms of the GNU General Public License version 2, as
#	published by the Free Software Foundation.
#	
#	ZXMedia is distributed in the hope that it will be useful,
#	but WITHOUT ANY WARRANTY; without even the implied warranty of
#	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#	GNU General Public License for more details.
#	
#	You should have received a copy of the GNU General Public License
#	along with ZXMedia; if not, write to the Free Software
#	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
#	Contact address: Matthew Westcott, 14 Daisy Hill Drive, Adlington,
#	Chorley, Lancs. PR6 9NE, United Kingdom

module ZXMedia

	##
	# A tape-specific block containing text fields listing publisher, year of release etc.
	# Only applicable to TZX-format tape images

	class ArchiveInfoTapeBlock < Block
		# This tape-specific block contains a set of strings listing metadata for the tape.
		# TODO: Parse the block into its individual fields.

		# Archive data, as an array of bytes. (Parsing into individual fields is not currently supported)

		attr_reader :data

		##
		# Create a new archive info block with the specified contents (given as an array of bytes)
		
		def initialize(data)
			@data = data
		end
		
		##
		# Write this block to an IO object in TZX format
		
		def write_tzx_block(io)
			io.putc 0x32
			io << Common.word_little_endian(@data.size).pack('c*')
			io << @data.pack('c*')
		end
		
		##
		# Write this block to an IO object in TAP format (has no effect)
		
		def write_tap_block(io)
			# this block can sensibly be dropped without warning when writing to TAP
		end
		
		##
		# Returns true, to indicate that this block does not interrupt loading of
		# header-datablock pairs from tape
		
		def preserves_tape_loading_continuity?
			true
		end

		##
		# Return a text description of this block

		def to_s
			"Archive info (#{@data.size} bytes)"
		end
		
	end # ArchiveInfoTapeBlock
end # ZXMedia