#	ZXMedia: ZX Spectrum file format manipulation library
#	Copyright (C) 2004 Matthew Westcott
#	
#	This file is part of ZXMedia.
#	
#	ZXMedia is free software; you can redistribute it and/or modify
#	it under the terms of the GNU General Public License version 2, as
#	published by the Free Software Foundation.
#	
#	ZXMedia is distributed in the hope that it will be useful,
#	but WITHOUT ANY WARRANTY; without even the implied warranty of
#	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#	GNU General Public License for more details.
#	
#	You should have received a copy of the GNU General Public License
#	along with ZXMedia; if not, write to the Free Software
#	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
#	Contact address: Matthew Westcott, 14 Daisy Hill Drive, Adlington,
#	Chorley, Lancs. PR6 9NE, United Kingdom

module ZXMedia

	##
	# A 17-byte tape header for either of the Spectrum's array formats.

	class ArrayHeaderTapeBlock < Block

		attr_accessor :datasource

 		# The value for the unused byte at position 14 in the header
 		attr_accessor :param1
 
 		# The value for the unused word at position 16 in the header
 		attr_accessor :param2

		attr_accessor :header_tape_block

		def initialize(datasource_or_filename, block_length = nil, variable_name = nil, param1 = 0, param2 = 0)
			if datasource_or_filename.is_a? String
				# filename supplied - other fields are required
				raise "block_length not specified for ArrayHeaderTapeBlock" if block_length.nil?
				raise "variable_name not specified for ArrayHeaderTapeBlock" if variable_name.nil?
				@datasource = nil
				self.filename = datasource_or_filename
				self.block_length = block_length
				self.variable_name = variable_name
			else
				# datasource supplied
				@datasource = datasource_or_filename
			end
			
			@param1 = param1
			@param2 = param2
			self.header_tape_block = HeaderTapeBlock.new(self)
		end
		
		def filename
			if @datasource.nil?
				@filename
			else
				@datasource.filename
			end
		end

		def filename=(f)
			raise "Cannot assign filename to this block directly" unless @datasource.nil?
			# trim / space-pad filename to 10 characters
			@filename = f.ljust(10)[0,10]
		end

		def block_length
			if @datasource.nil?
				@block_length
			else
				@datasource.block_length
			end
		end

		def block_length=(block_length)
			raise "Cannot assign block_length to this block directly" unless @datasource.nil?
			@block_length = block_length
		end

		def variable_name
			if @datasource.nil?
				@variable_name
			else
				@datasource.variable_name
			end
		end

		def variable_name=(variable_name)
			raise "Cannot assign variable_name to this block directly" unless @datasource.nil?
			@variable_name = variable_name
		end

		def write_tap_block(io)
			self.header_tape_block.write_tap_block(io)
		end
		
		def write_tzx_block(io)
			self.header_tape_block.write_tzx_block(io)
		end

	end # ArrayHeaderTapeBlock
end # ZXMedia