#	ZXMedia: ZX Spectrum file format manipulation library
#	Copyright (C) 2004 Matthew Westcott
#	
#	This file is part of ZXMedia.
#	
#	ZXMedia is free software; you can redistribute it and/or modify
#	it under the terms of the GNU General Public License version 2, as
#	published by the Free Software Foundation.
#	
#	ZXMedia is distributed in the hope that it will be useful,
#	but WITHOUT ANY WARRANTY; without even the implied warranty of
#	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#	GNU General Public License for more details.
#	
#	You should have received a copy of the GNU General Public License
#	along with ZXMedia; if not, write to the Free Software
#	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
#	Contact address: Matthew Westcott, 14 Daisy Hill Drive, Adlington,
#	Chorley, Lancs. PR6 9NE, United Kingdom

module ZXMedia

	##
	# A 17-byte header for a Bytes: block on a tape.

	class BytesHeaderTapeBlock < Block
		
		attr_accessor(:datasource, :param2, :header_tape_block)

		def initialize(datasource_or_filename, block_length = nil, start_address = nil, param2 = 32768)
			if datasource_or_filename.is_a? String
				# filename supplied - other fields are required
				raise "block_length not specified for BytesHeaderTapeBlock" if block_length.nil?
				raise "start_address not specified for BytesHeaderTapeBlock" if start_address.nil?
				@datasource = nil
				self.filename = datasource_or_filename
				self.block_length = block_length
				self.start_address = start_address
			else
				# datasource supplied
				@datasource = datasource_or_filename
			end

			@param2 = param2
			self.header_tape_block = HeaderTapeBlock.new(self)
		end
		
		def filename
			if @datasource.nil?
				@filename
			else
				@datasource.filename
			end
		end

		def filename=(f)
			raise "Cannot assign filename to this block directly" unless @datasource.nil?
			# trim / space-pad filename to 10 characters
			@filename = f.ljust(10)[0,10]
		end

		def block_length
			if @datasource.nil?
				@block_length
			else
				@datasource.block_length
			end
		end

		def block_length=(block_length)
			raise "Cannot assign block_length to this block directly" unless @datasource.nil?
			@block_length = block_length
		end

		def start_address
			if @datasource.nil?
				@start_address
			else
				@datasource.start_address
			end
		end

		def start_address=(start_address)
			raise "Cannot assign start_address to this block directly" unless @datasource.nil?
			@start_address = start_address
		end

		def header_type_id
			3
		end

		def header_tape_extra_data
			Common.word_little_endian(self.start_address) + Common.word_little_endian(@param2)
		end

		def to_s
			"Header for bytes \'#{self.filename}\' CODE #{self.start_address},#{self.block_length}"
		end

		def write_tap_block(io)
			self.header_tape_block.write_tap_block(io)
		end
		
		def write_tzx_block(io)
			self.header_tape_block.write_tzx_block(io)
		end

		def BytesHeaderTapeBlock.can_promote?(block)
			if block.is_a? HeaderTapeBlock
				block.header_type_id == 3 && block.extra_data.size == 4
			else
				false
			end
		end

		def BytesHeaderTapeBlock.promote(block)
			data = block.extra_data
			start_address = data[0] | (data[1] << 8)
			param2 = data[2] | (data[3] << 8)
			bhtb = BytesHeaderTapeBlock.new(block.filename, block.block_length, start_address, param2)
			block.datasource = bhtb
			bhtb.header_tape_block = block
			bhtb
		end

	end # BytesHeaderTapeBlock
end # ZXMedia