#	ZXMedia: ZX Spectrum file format manipulation library
#	Copyright (C) 2004 Matthew Westcott
#	
#	This file is part of ZXMedia.
#	
#	ZXMedia is free software; you can redistribute it and/or modify
#	it under the terms of the GNU General Public License version 2, as
#	published by the Free Software Foundation.
#	
#	ZXMedia is distributed in the hope that it will be useful,
#	but WITHOUT ANY WARRANTY; without even the implied warranty of
#	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#	GNU General Public License for more details.
#	
#	You should have received a copy of the GNU General Public License
#	along with ZXMedia; if not, write to the Free Software
#	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
#	Contact address: Matthew Westcott, 14 Daisy Hill Drive, Adlington,
#	Chorley, Lancs. PR6 9NE, United Kingdom

module ZXMedia
	class CustomInfoTapeBlock < Block
		# This tape-specific block stores arbitrary custom information.
		# TODO: Fully parse the standardised types listed in the TZX spec
		attr_writer :id
		attr_reader(:id, :data)

		def initialize(id, data)
			@id = id
			@data = data
		end
		
		def write_tzx_block(io)
			io.putc 0x35
			io.write @id.ljust(10)[0,10]
			io << Common.dword_little_endian(@data.size).pack('c*')
			io << @data.pack('c*')
		end

		def write_tap_block(io)
			# this block can sensibly be dropped without warning when writing to TAP
		end

		def preserves_tape_loading_continuity?
			true
		end

		def to_s
			"Custom information, type \"#{@id}\" (#{@data.size} bytes)"
		end

	end # CustomInfoTapeBlock
end # ZXMedia