#	ZXMedia: ZX Spectrum file format manipulation library
#	Copyright (C) 2004 Matthew Westcott
#	
#	This file is part of ZXMedia.
#	
#	ZXMedia is free software; you can redistribute it and/or modify
#	it under the terms of the GNU General Public License version 2, as
#	published by the Free Software Foundation.
#	
#	ZXMedia is distributed in the hope that it will be useful,
#	but WITHOUT ANY WARRANTY; without even the implied warranty of
#	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#	GNU General Public License for more details.
#	
#	You should have received a copy of the GNU General Public License
#	along with ZXMedia; if not, write to the Free Software
#	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
#	Contact address: Matthew Westcott, 14 Daisy Hill Drive, Adlington,
#	Chorley, Lancs. PR6 9NE, United Kingdom

module ZXMedia
	class EmulationInfoTapeBlock < Block
		# This tape-specific block stores information about the features of the emulator that created the file
		
		attr_reader(:r_register, :ldir, :high_res_color, :video_sync, :fast_loading, :border, :screen_refresh, :auto_start_tape, :auto_load, :screen_refresh_delay, :interrupt_frequency, :reserved_bits, :reserved)
		attr_writer(:r_register, :ldir, :high_res_color, :video_sync, :fast_loading, :border, :screen_refresh, :auto_start_tape, :auto_load, :screen_refresh_delay, :interrupt_frequency, :reserved_bits, :reserved)

		def initialize(r_register = true, ldir = true, high_res_color = true, video_sync = 0, fast_loading = true, border = true, screen_refresh = true, auto_start_tape = false, auto_load = false, screen_refresh_delay = 1, interrupt_frequency = 50, reserved_bits = 0, reserved = 0)
			@r_register = r_register
			@ldir = ldir
			@high_res_color = high_res_color
			@video_sync = video_sync
			@fast_loading = fast_loading
			@border = border
			@screen_refresh = screen_refresh
			@auto_start_tape = auto_start_tape
			@auto_load = auto_load
			@screen_refresh_delay = screen_refresh_delay
			@interrupt_frequency = interrupt_frequency
			@reserved_bits = reserved_bits
			@reserved = reserved
		end
		
		def write_tzx_block(io)
			io.putc 0x34
			io.putc(
				(@r_register ? 0x01 : 0) |
				(@ldir ? 0x02 : 0) |
				(@high_res_color ? 0x04 : 0) |
				(@video_sync << 3) |
				(@fast_loading ? 0x20 : 0) |
				(@border ? 0x40 : 0) |
				(@screen_refresh ? 0x80 : 0)
			)
			io.putc(
				(@auto_start_tape ? 0x01 : 0) |
				(@auto_load ? 0x02 : 0) |
				(@reserved_bits << 2)
			)
			io.putc @screen_refresh_delay
			io << Common.word_little_endian(@interrupt_frequency).pack('c*')
			io << Common.triplet_little_endian(@reserved).pack('c*')
		end

		def write_tap_block(io)
			# this block can sensibly be dropped without warning when writing to TAP
		end

		def preserves_tape_loading_continuity?
			true
		end

		def to_s
			"Emulation info block"
		end

	end # EmulationInfoTapeBlock
end # ZXMedia