#	ZXMedia: ZX Spectrum file format manipulation library
#	Copyright (C) 2004 Matthew Westcott
#	
#	This file is part of ZXMedia.
#	
#	ZXMedia is free software; you can redistribute it and/or modify
#	it under the terms of the GNU General Public License version 2, as
#	published by the Free Software Foundation.
#	
#	ZXMedia is distributed in the hope that it will be useful,
#	but WITHOUT ANY WARRANTY; without even the implied warranty of
#	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#	GNU General Public License for more details.
#	
#	You should have received a copy of the GNU General Public License
#	along with ZXMedia; if not, write to the Free Software
#	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
#	Contact address: Matthew Westcott, 14 Daisy Hill Drive, Adlington,
#	Chorley, Lancs. PR6 9NE, United Kingdom

module ZXMedia
	class PureDataTapeBlock < Block
		# This tape-specific block represents a data chunk with arbitrary timings and no pilot or sync pulses

		attr_reader(:zero_bit_pulse_length, :one_bit_pulse_length, :trailing_bits, :trailing_pause_length, :data)
		attr_writer(:zero_bit_pulse_length, :one_bit_pulse_length, :trailing_bits, :trailing_pause_length)

		def initialize(data, zero_bit_pulse_length = 855, one_bit_pulse_length = 1710, trailing_bits = 8, trailing_pause_length = 1000)
			@data = data
			@zero_bit_pulse_length = zero_bit_pulse_length
			@one_bit_pulse_length = one_bit_pulse_length
			@trailing_bits = trailing_bits
			@trailing_pause_length = trailing_pause_length
		end
		
		def write_tzx_block(io)
			io.putc 0x14
			io << Common.word_little_endian(@zero_bit_pulse_length).pack('c*')
			io << Common.word_little_endian(@one_bit_pulse_length).pack('c*')
			io.putc @trailing_bits
			io << Common.word_little_endian(@trailing_pause_length).pack('c*')
			io << Common.triplet_little_endian(@data.size).pack('c*')
			io << @data.pack('c*')
		end
		
		def bit_count
			8 * (@data.size - 1) + @trailing_bits
		end
		
		def to_s
			"Pure data (#{bit_count} bits)"
		end
		
	end # PureDataTapeBlock
end # ZXMedia