#	ZXMedia: ZX Spectrum file format manipulation library
#	Copyright (C) 2004 Matthew Westcott
#	
#	This file is part of ZXMedia.
#	
#	ZXMedia is free software; you can redistribute it and/or modify
#	it under the terms of the GNU General Public License version 2, as
#	published by the Free Software Foundation.
#	
#	ZXMedia is distributed in the hope that it will be useful,
#	but WITHOUT ANY WARRANTY; without even the implied warranty of
#	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#	GNU General Public License for more details.
#	
#	You should have received a copy of the GNU General Public License
#	along with ZXMedia; if not, write to the Free Software
#	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
#	Contact address: Matthew Westcott, 14 Daisy Hill Drive, Adlington,
#	Chorley, Lancs. PR6 9NE, United Kingdom

module ZXMedia
	class PureToneTapeBlock < Block
		# This tape-specific block represents a pure square-wave tone, like a pilot tone from a standard tape block

		attr_reader(:pulse_length, :pulse_count)
		attr_writer(:pulse_length, :pulse_count)

		def initialize(pulse_length, pulse_count)
			@pulse_length = pulse_length
			@pulse_count = pulse_count
		end
		
		def write_tzx_block(io)
			io.putc 0x12
			io << Common.word_little_endian(@pulse_length).pack('c*')
			io << Common.word_little_endian(@pulse_count).pack('c*')
		end
		
		def pulse_frequency
			3500000 / @pulse_length
		end
		
		def to_s
			"Pure tone (#{@pulse_count} pulses @ #{pulse_frequency}Hz)"
		end
		
	end # PureToneTapeBlock
end # ZXMedia