#	ZXMedia: ZX Spectrum file format manipulation library
#	Copyright (C) 2004 Matthew Westcott
#	
#	This file is part of ZXMedia.
#	
#	ZXMedia is free software; you can redistribute it and/or modify
#	it under the terms of the GNU General Public License version 2, as
#	published by the Free Software Foundation.
#	
#	ZXMedia is distributed in the hope that it will be useful,
#	but WITHOUT ANY WARRANTY; without even the implied warranty of
#	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#	GNU General Public License for more details.
#	
#	You should have received a copy of the GNU General Public License
#	along with ZXMedia; if not, write to the Free Software
#	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
#	Contact address: Matthew Westcott, 14 Daisy Hill Drive, Adlington,
#	Chorley, Lancs. PR6 9NE, United Kingdom

module ZXMedia
	class UnknownHeaderTapeBlock < HeaderTapeBlock
		# This class represents a 17-byte tape header where the header ID is not one of the recognised types
		
		attr_reader(:header_id, :extra_data)
		attr_writer :header_id

		def initialize(header_id, filename, block_length, extra_data)
			@header_id = header_id
			@filename = filename
			@block_length = block_length
			@extra_data = @extra_data
			
			super(0, nil) # saved_data accessor of ROMTapeBlock is overridden here, so it doesn't matter
				# what we put for the saved_data parameter above
		end
		
		def saved_data
			[@header_id] + self.filename_bytes + Common.word_little_endian(@block_length) + @extra_data
		end

		def to_s
			"Header for file \'#{@filename.ljust(10)[0,10]}\' of unknown type"
		end

	end # UnknownHeaderTapeBlock
end # ZXMedia