#	ZXMedia: ZX Spectrum file format manipulation library
#	Copyright (C) 2004 Matthew Westcott
#	
#	This file is part of ZXMedia.
#	
#	ZXMedia is free software; you can redistribute it and/or modify
#	it under the terms of the GNU General Public License version 2, as
#	published by the Free Software Foundation.
#	
#	ZXMedia is distributed in the hope that it will be useful,
#	but WITHOUT ANY WARRANTY; without even the implied warranty of
#	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#	GNU General Public License for more details.
#	
#	You should have received a copy of the GNU General Public License
#	along with ZXMedia; if not, write to the Free Software
#	Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
#	Contact address: Matthew Westcott, 14 Daisy Hill Drive, Adlington,
#	Chorley, Lancs. PR6 9NE, United Kingdom

module ZXMedia
	class UnknownTapeBlock < Block
		# This class is a catch-all for TZX blocks with unrecognised IDs. These are
		# assumed to follow the TZX extension rule, i.e. the block starts with a
		# four-byte length indicator.

		attr_reader(:id, :data)
		attr_writer :id

		def initialize(id, data)
			@id = id
			@data = data
		end
		
		def write_tzx_block(io)
			io.putc @id
			io << Common.dword_little_endian(@data.size).pack('c*')
			io << @data.pack('c*')
		end
		
		def to_s
			"Unknown block (ID #{@id}, #{@data.size} bytes)"
		end
		
	end # UnknownTapeBlock
end # ZXMedia